#
# spec file for package ibsim
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define git_ver .0.db9c0e46bf23

Name:           ibsim
Version:        0.12
Release:        3.3
Summary:        InfiniBand fabric simulator for management
License:        BSD-2-Clause OR GPL-2.0-only
Group:          Productivity/Networking/Diagnostic
Source:         ibsim-%{version}%{git_ver}.tar.gz
Patch1:         ibsim-PIE.patch
URL:            https://github.com/linux-rdma/ibsim
BuildRequires:  infiniband-diags-devel
BuildRequires:  libibumad-devel
BuildRequires:  make

%description
ibsim provides simulation of infiniband fabric for using with OFA
OpenSM, diagnostic and management tools.

%prep
%autosetup -p0 -n  %{name}-%{version}%{git_ver}

%build
export CFLAGS="%{optflags}"
export LDFLAGS="%{optflags}"
make prefix=%_prefix libpath=%_libdir binpath=%_bindir %{?_smp_mflags}

%install
export CFLAGS="%{optflags}"
export LDFLAGS="%{optflags}"
%make_install prefix=%_prefix libpath=%_libdir binpath=%_bindir

%files
%dir %{_libdir}/umad2sim
%{_libdir}/umad2sim/libumad2sim*.so*
%{_bindir}/ibsim
%{_bindir}/ibsim-run
%doc README TODO net-examples scripts
%license COPYING

%changelog
* Wed Feb  5 2025 Nicolas Morey <nicolas.morey@suse.com>
- Fix new line issues in changelog
* Thu Feb 22 2024 Dominique Leuenberger <dimstar@opensuse.org>
- Use %%autosetup macro. Allows to eliminate the usage of deprecated
  %%patchN
* Tue Jul 25 2023 Nicolas Morey <nicolas.morey@suse.com>
- Update to 0.12
  - Increase LFT size to 48K
  - Support NDR when parsing enhance ibnetdiscover
  - Enable IsLinkSpeedNDRSupported bit in PortInfo
  - Assume QDR speed when port speed is 0
* Mon Aug 23 2021 Nicolas Morey-Chaisemartin <nmoreychaisemartin@suse.com>
- Update to 0.11
  - Fixes various compilations warnings
  - Initial NDR support
  - Remove IsVendorClassSupported capibility bit from HCA
- Drop patches fixed upstream:
  - ibsim-fix_type_punning.patch
  - typo-scrips.patch
* Wed Apr 28 2021 Nicolas Morey-Chaisemartin <nmoreychaisemartin@suse.com>
- Update to version 0.10
  - Support multiple umad file descriptors
  - Support latest libibumad
  - Added ibsim-run, a wrapper to run programs under ibsim
- Refresh ibsim-PIE.patch against latest sources
- Add typo-scrips.patch to fix compilation for ibsim-run
* Thu Apr 22 2021 Jan Engelhardt <jengelh@inai.de>
- Trim old rpm constructs.
* Thu Apr 15 2021 Wolfgang Frisch <wolfgang.frisch@suse.com>
- Hardening: Link as Position Independent Executable.
  - Added ibsim-PIE.patch
* Tue Mar  3 2020 Nicolas Morey-Chaisemartin <nmoreychaisemartin@suse.com>
- Update to version 0.9
  - Add --no-console option
  - Support GID/subnet prefix field in the PortInfo attribute
- Drop patches merged upstream:
  - umad2sim-Do-not-use-umad.h-deprecated-functions.patch
  - umad2sim-define-UMAD_DEV_DIR-if-not-set.patch
* Fri Oct 11 2019 Nicolas Morey-Chaisemartin <nmoreychaisemartin@suse.com>
- Add patches to fix support with rdma-core >= 25
  - umad2sim-Do-not-use-umad.h-deprecated-functions.patch
  - umad2sim-define-UMAD_DEV_DIR-if-not-set.patch
* Thu Apr 18 2019 Nicolas Morey-Chaisemartin <nmoreychaisemartin@suse.com>
- Remove unneeded build dependencies
* Wed Apr 17 2019 Nicolas Morey-Chaisemartin <nmoreychaisemartin@suse.com>
- Update to version 0.8
  - Extended speed support including HDR and FDR10
  - 2x link support
  - Link speed, espeed, and width change support
  - Support for PortXmitWait field in PortCounters
  - Minor changes/bug fixes
* Fri Jun 15 2018 nmoreychaisemartin@suse.com
- Update Source and URL as ibsim was moved to GitHub
- Add a _service file to be able to auto-fetch from github
* Fri Jun 23 2017 nmoreychaisemartin@suse.com
- Replace dependency from libibmad-devel to infiniband-diags-devel
* Thu Jun  8 2017 nmoreychaisemartin@suse.com
- Update to version 0.7
  * PerformanceSet handling for enhanced switch port 0
  * Fix incorrectly updated port counters in pc_updated()
  * Invalidate PerformanceSet commands with no port number
  * Fix parsing of port number in PerformanceSet command
  * Allocate MFT according to number of switch ports
* Wed Mar 29 2017 pth@suse.de
- Make dependencies on libs now coming from rdma-core versioned.
* Thu Mar 10 2016 pth@suse.de
- Update to latest git version 0.6-gitf9acb41 (bsc#970668):
  * sim_cmd.c: PerformanceSet handling for enhanced switch port 0
    Setting the perf counters of the port 0 is only allowed when
    the node is a switch with an enhanced port 0
  * sim_mad.c: Fix incorrectly updated port counters in pc_updated()
    When the IB packet gets out of the source port,
    the Xmit fields of the source port are now updated.
  * sim_cmd.c: Invalidate PerformanceSet commands with no port number
    Syntax: sim> PerformanceSet "nodeid"[port] [attribute].[field]=[value]
  * sim_cmd.c: Fix parsing of port number in PerformanceSet command
    Syntax: sim> PerformanceSet "nodeid"[port] [attribute].[field]=[value]
  * ibsim: Allocate MFT according to number of switch ports
    Calculate number of port masks according to number of switch ports
    and allocate MFT accordingly
- Include ChangeLog generated from git log.
- Add ibsim-fix_type_punning.patch to replace type-punning by
  memcpy.
* Wed Jun 25 2014 pth@suse.de
- Don't use a full source URL as a package with the current version
  isn't anymore available standalone.
* Tue Jun  3 2014 pth@suse.de
- Update to OFED 3.12 final.
* Fri Feb 14 2014 pth@suse.de
- Remove an empty macro which the rpm parser won't grok.
* Thu Feb 13 2014 pth@suse.de
- Update to 0.6 for fate#315488. No Changelog in package.
- Use full source URI and don't recompress the tarball.
* Fri Jan 24 2014 pth@suse.de
- Update to OFED 3.12 daily
* Tue May  8 2012 pth@suse.de
- BuildRequire automake, autoconf and libtool.
* Thu Feb  3 2011 ro@suse.de
- correct buildrequirs to libibmad-devel
* Fri Oct 29 2010 stefan.fent@novell.com
- correct requires to libibumad-devel
* Wed Oct 27 2010 jjolly@novell.com
- Updated to v0.5-0.1.g327c3d8 from OFED 1.5.2
* Thu Dec 11 2008 jjolly@suse.de
- Updated to v0.5 from OFED 1.4 GA
  - No changelog provided
* Thu Nov 13 2008 ro@suse.de
- excludearch s390
* Mon Oct 27 2008 jjolly@suse.de
- Updated to version from OFED 1.4 rc3
- bzipped source tarball
* Wed Sep 10 2008 jjolly@suse.de
- Recreated the package for SLES11
